==> camel-k-model-v1alpha1-6.1.1-sources.jar: io/fabric8/camelk/v1alpha1/KameletStatusFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KameletStatusFluent<A extends KameletStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,KameletCondition item);
  public A setToConditions(Integer index,KameletCondition item);
  public A addToConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items);
  public A addAllToConditions(Collection<KameletCondition> items);
  public A removeFromConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items);
  public A removeAllFromConditions(Collection<KameletCondition> items);
  public A removeMatchingFromConditions(Predicate<KameletConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletCondition> getConditions();
  public List<KameletCondition> buildConditions();
  public KameletCondition buildCondition(Integer index);
  public KameletCondition buildFirstCondition();
  public KameletCondition buildLastCondition();
  public KameletCondition buildMatchingCondition(Predicate<KameletConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<KameletConditionBuilder> predicate);
  public A withConditions(List<KameletCondition> conditions);
  public A withConditions(io.fabric8.camelk.v1alpha1.KameletCondition... conditions);
  public Boolean hasConditions();
  public KameletStatusFluent.ConditionsNested<A> addNewCondition();
  public KameletStatusFluent.ConditionsNested<A> addNewConditionLike(KameletCondition item);
  public KameletStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,KameletCondition item);
  public KameletStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public KameletStatusFluent.ConditionsNested<A> editFirstCondition();
  public KameletStatusFluent.ConditionsNested<A> editLastCondition();
  public KameletStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<KameletConditionBuilder> predicate);
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public A addToProperties(Integer index,KameletProperty item);
  public A setToProperties(Integer index,KameletProperty item);
  public A addToProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items);
  public A addAllToProperties(Collection<KameletProperty> items);
  public A removeFromProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items);
  public A removeAllFromProperties(Collection<KameletProperty> items);
  public A removeMatchingFromProperties(Predicate<KameletPropertyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildProperties instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletProperty> getProperties();
  public List<KameletProperty> buildProperties();
  public KameletProperty buildProperty(Integer index);
  public KameletProperty buildFirstProperty();
  public KameletProperty buildLastProperty();
  public KameletProperty buildMatchingProperty(Predicate<KameletPropertyBuilder> predicate);
  public Boolean hasMatchingProperty(Predicate<KameletPropertyBuilder> predicate);
  public A withProperties(List<KameletProperty> properties);
  public A withProperties(io.fabric8.camelk.v1alpha1.KameletProperty... properties);
  public Boolean hasProperties();
  public A addNewProperty(String _default,String name);
  public KameletStatusFluent.PropertiesNested<A> addNewProperty();
  public KameletStatusFluent.PropertiesNested<A> addNewPropertyLike(KameletProperty item);
  public KameletStatusFluent.PropertiesNested<A> setNewPropertyLike(Integer index,KameletProperty item);
  public KameletStatusFluent.PropertiesNested<A> editProperty(Integer index);
  public KameletStatusFluent.PropertiesNested<A> editFirstProperty();
  public KameletStatusFluent.PropertiesNested<A> editLastProperty();
  public KameletStatusFluent.PropertiesNested<A> editMatchingProperty(Predicate<KameletPropertyBuilder> predicate);
  public interface ConditionsNested<N> extends Nested<N>,KameletConditionFluent<KameletStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface PropertiesNested<N> extends Nested<N>,KameletPropertyFluent<KameletStatusFluent.PropertiesNested<N>>{
    public N and();
    public N endProperty();
    
  }
  
}

==> camel-k-model-v1alpha1-6.7.2-sources.jar: io/fabric8/camelk/v1alpha1/KameletStatusFluent.java <==
package io.fabric8.camelk.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KameletStatusFluent<A extends KameletStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,KameletCondition item);
  public A setToConditions(int index,KameletCondition item);
  public A addToConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items);
  public A addAllToConditions(Collection<KameletCondition> items);
  public A removeFromConditions(io.fabric8.camelk.v1alpha1.KameletCondition... items);
  public A removeAllFromConditions(Collection<KameletCondition> items);
  public A removeMatchingFromConditions(Predicate<KameletConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletCondition> getConditions();
  public List<KameletCondition> buildConditions();
  public KameletCondition buildCondition(int index);
  public KameletCondition buildFirstCondition();
  public KameletCondition buildLastCondition();
  public KameletCondition buildMatchingCondition(Predicate<KameletConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<KameletConditionBuilder> predicate);
  public A withConditions(List<KameletCondition> conditions);
  public A withConditions(io.fabric8.camelk.v1alpha1.KameletCondition... conditions);
  public Boolean hasConditions();
  public KameletStatusFluent.ConditionsNested<A> addNewCondition();
  public KameletStatusFluent.ConditionsNested<A> addNewConditionLike(KameletCondition item);
  public KameletStatusFluent.ConditionsNested<A> setNewConditionLike(int index,KameletCondition item);
  public KameletStatusFluent.ConditionsNested<A> editCondition(int index);
  public KameletStatusFluent.ConditionsNested<A> editFirstCondition();
  public KameletStatusFluent.ConditionsNested<A> editLastCondition();
  public KameletStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<KameletConditionBuilder> predicate);
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public A addToProperties(int index,KameletProperty item);
  public A setToProperties(int index,KameletProperty item);
  public A addToProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items);
  public A addAllToProperties(Collection<KameletProperty> items);
  public A removeFromProperties(io.fabric8.camelk.v1alpha1.KameletProperty... items);
  public A removeAllFromProperties(Collection<KameletProperty> items);
  public A removeMatchingFromProperties(Predicate<KameletPropertyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildProperties instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<KameletProperty> getProperties();
  public List<KameletProperty> buildProperties();
  public KameletProperty buildProperty(int index);
  public KameletProperty buildFirstProperty();
  public KameletProperty buildLastProperty();
  public KameletProperty buildMatchingProperty(Predicate<KameletPropertyBuilder> predicate);
  public Boolean hasMatchingProperty(Predicate<KameletPropertyBuilder> predicate);
  public A withProperties(List<KameletProperty> properties);
  public A withProperties(io.fabric8.camelk.v1alpha1.KameletProperty... properties);
  public Boolean hasProperties();
  public A addNewProperty(String _default,String name);
  public KameletStatusFluent.PropertiesNested<A> addNewProperty();
  public KameletStatusFluent.PropertiesNested<A> addNewPropertyLike(KameletProperty item);
  public KameletStatusFluent.PropertiesNested<A> setNewPropertyLike(int index,KameletProperty item);
  public KameletStatusFluent.PropertiesNested<A> editProperty(int index);
  public KameletStatusFluent.PropertiesNested<A> editFirstProperty();
  public KameletStatusFluent.PropertiesNested<A> editLastProperty();
  public KameletStatusFluent.PropertiesNested<A> editMatchingProperty(Predicate<KameletPropertyBuilder> predicate);
  public interface ConditionsNested<N> extends Nested<N>,KameletConditionFluent<KameletStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface PropertiesNested<N> extends Nested<N>,KameletPropertyFluent<KameletStatusFluent.PropertiesNested<N>>{
    public N and();
    public N endProperty();
    
  }
  
}
